==> auctex-11.86-pkg.tar.gz: lisp/auctex/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'TeX-fold '("latex" "tex-fold"))
(custom-add-loads 'AUCTeX-jp '("tex-jp"))
(custom-add-loads 'tex '("bib-cite" "font-latex" "texmathp"))
(custom-add-loads 'ConTeXt-nl-environment '("context-nl"))
(custom-add-loads 'TeX-tool-bar-button-definitions '("tex-bar"))
(custom-add-loads 'LaTeX-label '("latex" "tex-style"))
(custom-add-loads 'LaTeX-environment '("latex"))
(custom-add-loads 'LaTeX-macro '("latex" "tex-style"))
(custom-add-loads 'TeX-tool-bar '("latex" "tex-bar" "tex"))
(custom-add-loads 'preview-appearance '("preview" "prv-xemacs"))
(custom-add-loads 'texmathp '("texmathp"))
(custom-add-loads 'TeX-output '("tex-buf" "tex"))
(custom-add-loads 'LaTeX-math '("latex"))
(custom-add-loads 'AUCTeX '("font-latex" "preview" "tex-bar" "tex-fold" "tex-jp" "tex"))
(custom-add-loads 'preview-latex '("preview" "prv-xemacs"))
(custom-add-loads 'TeX-parse '("tex"))
(custom-add-loads 'TeX-command '("context" "latex" "tex-buf" "tex-info" "tex"))
(custom-add-loads 'TeX-command-name '("tex"))
(custom-add-loads 'preview '("preview"))
(custom-add-loads 'bib-cite '("bib-cite"))
(custom-add-loads 'TeX-indentation '("latex" "tex"))
(custom-add-loads 'LaTeX-style '("tex-style"))
(custom-add-loads 'font-latex-keywords '("font-latex"))
(custom-add-loads 'font-latex '("font-latex"))
(custom-add-loads 'font-latex-highlighting-faces '("font-latex"))
(custom-add-loads 'TeX-macro '("context" "latex" "tex"))
(custom-add-loads 'TeX-quote '("tex"))
(custom-add-loads 'faces '("font-latex"))
(custom-add-loads 'ConTeXt-en-environment '("context-en"))
(custom-add-loads 'ConTeXt '("context"))
(custom-add-loads 'LaTeX-indentation '("latex"))
(custom-add-loads 'LaTeX '("latex" "tex"))
(custom-add-loads 'TeX-misc '("tex"))
(custom-add-loads 'preview-gs '("preview"))
(custom-add-loads 'ConTeXt-macro '("context"))
(custom-add-loads 'TeX-file-extension '("tex"))
(custom-add-loads 'TeX-view '("tex"))
(custom-add-loads 'ConTeXt-environment '("context"))
(custom-add-loads 'TeX-file '("tex"))

;;; custom-load.el ends here

==> auctex-11.87-pkg.tar.gz: lisp/auctex/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'TeX-fold '("latex" "tex-fold"))
(custom-add-loads 'AUCTeX-jp '("tex-jp"))
(custom-add-loads 'tex '("bib-cite" "font-latex" "texmathp"))
(custom-add-loads 'ConTeXt-nl-environment '("context-nl"))
(custom-add-loads 'TeX-tool-bar-button-definitions '("tex-bar"))
(custom-add-loads 'LaTeX-label '("latex" "tex-style"))
(custom-add-loads 'LaTeX-environment '("latex"))
(custom-add-loads 'LaTeX-macro '("latex" "tex-style"))
(custom-add-loads 'TeX-tool-bar '("latex" "plain-tex" "tex-bar"))
(custom-add-loads 'preview-appearance '("preview" "prv-xemacs"))
(custom-add-loads 'texmathp '("texmathp"))
(custom-add-loads 'TeX-output '("tex-buf" "tex"))
(custom-add-loads 'LaTeX-math '("latex"))
(custom-add-loads 'AUCTeX '("font-latex" "preview" "tex-bar" "tex-fold" "tex-jp" "tex"))
(custom-add-loads 'preview-latex '("preview" "prv-xemacs"))
(custom-add-loads 'TeX-parse '("tex"))
(custom-add-loads 'TeX-command '("context" "latex" "plain-tex" "tex-buf" "tex-info" "tex"))
(custom-add-loads 'TeX-command-name '("tex"))
(custom-add-loads 'preview '("preview"))
(custom-add-loads 'bib-cite '("bib-cite"))
(custom-add-loads 'TeX-indentation '("latex" "tex"))
(custom-add-loads 'LaTeX-style '("tex-style"))
(custom-add-loads 'font-latex-keywords '("font-latex"))
(custom-add-loads 'font-latex '("font-latex"))
(custom-add-loads 'font-latex-highlighting-faces '("font-latex"))
(custom-add-loads 'TeX-macro '("context" "latex" "tex"))
(custom-add-loads 'TeX-quote '("tex"))
(custom-add-loads 'faces '("font-latex"))
(custom-add-loads 'ConTeXt-en-environment '("context-en"))
(custom-add-loads 'ConTeXt '("context"))
(custom-add-loads 'LaTeX-indentation '("latex"))
(custom-add-loads 'LaTeX '("latex" "tex"))
(custom-add-loads 'TeX-misc '("plain-tex" "tex"))
(custom-add-loads 'preview-gs '("preview"))
(custom-add-loads 'ConTeXt-macro '("context"))
(custom-add-loads 'TeX-file-extension '("tex"))
(custom-add-loads 'TeX-view '("tex"))
(custom-add-loads 'ConTeXt-environment '("context"))
(custom-add-loads 'TeX-file '("latex" "tex"))

;;; custom-load.el ends here
